``plover.machine.keymap`` -- Machine key bindings
=================================================

.. automodule:: plover.machine.keymap
   :members:
   :member-order: bysource
   :special-members: __getitem__, __setitem__
